@@ -6,7 +6,6 @@ from .lark_bitable import (
     BitableBaseRecord,
     bitable_field_metadata,
     parse_bitable_record,
-    RecordEncoder,
     bitable_record,
     BitableRecordService,
 )
@@ -22,7 +21,6 @@ __all__ = [
     "BitableBaseRecord",
     "bitable_field_metadata",
     "parse_bitable_record",
-    "RecordEncoder",
     "bitable_record",
     "BitableRecordService",
     "get_tenant_access_token",
